@@ -1,7 +1,14 @@
 import torch
 
 from ..containers import KeyEnforcer
-from ..hooks import CDANHook, DomainConfusionHook, GANHook, VADAHook
+from ..hooks import (
+    CDANEHook,
+    CDANHook,
+    DomainConfusionHook,
+    GANEHook,
+    GANHook,
+    VADAHook,
+)
 from ..utils import common_functions as c_f
 from .base_adapter import BaseGCDAdapter
 
@@ -19,6 +26,10 @@ class GAN(BaseGCDAdapter):
         self.hook = self.hook_cls(d_opts=d_opts, g_opts=g_opts, **hook_kwargs)
 
 
+class GANE(GAN):
+    hook_cls = GANEHook
+
+
 class CDAN(GAN):
     """
     Wraps [CDANHook][pytorch_adapt.hooks.cdan].
@@ -32,6 +43,10 @@ class CDAN(GAN):
         return ke
 
 
+class CDANE(CDAN):
+    hook_cls = CDANEHook
+
+
 class DomainConfusion(GAN):
     """
     Wraps [DomainConfusionHook][pytorch_adapt.hooks.domain_confusion].
